<?php

namespace PAR\Factory;

use Doctrine\ORM\EntityManager;
use PAR\Traits\TQuery;

class BusinessPartnerFactory {

    use TQuery;

    protected $connection;
    protected $entityManager;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getBusinessPartner() {

      $sql = "SELECT TPC.NMCLASSIFICAPARC,
               TPC.NRTPCLASSIFICAPARC,
               PN.NRPARCNEGOCIO,
               PN.CDSEGMER,
               SM.DSSEGMER,
               PN.CDTIPOPARCPRINCIPAL,
               TP.NMTIPOPARCEIRO AS NMTIPOPARCPRINCIPAL,
               PN.CDTIPOINSCRICAO,
               PN.NMPRINCIPALPARC,
               PN.NMSECUNDARIPARC,
               PN.DTNASCIFUNDPARC,
               PN.NRINSCRICAOPARC,
               PN.IDPESSOAFISICA,
               PN.IDINSTITUICAO,
               PN.NRORG,
               PN.IDATIVO,
               PN.DTINCLUSAO,
               PN.DTULTATU,
               PN.CDOPERRESPONSAVEL,
               PN.NRORGINCLUSAO,
               PN.CDOPERINCLUSAO,
               PN.NRORGULTATU,
               PN.CDOPERULTATU,
               PN.DSDEPARTAMENTO,
               PN.CDATIVCLI,
               AC.DSATIVCLI,
               PN.NRSEQTPATIVCLI,
               TC.DSTPATIVCLIENTE,
               PN.IDIDIOMA,
               LISTAGG(PA.CDTIPOPARCEIRO, ', ') WITHIN GROUP(ORDER BY PA.CDTIPOPARCEIRO) TIPODEPARCEIRO,
               INC.NMOPERADOR AS NMOPERINCLUSAO,
               ATU.NMOPERADOR AS NMOPERULTATU,
               OP.NMOPERADOR AS NMOPERRESPONSAVEL
          FROM PARCNEGOCIO PN
          LEFT JOIN PARCERIA PA
            ON PN.NRPARCNEGOCIO = PA.NRPARCNEGOCIO
           AND PA.IDATIVO       = 'S'
          LEFT JOIN TIPOCLASSIFICAPARC TPC
            ON PN.NRTPCLASSIFICAPARC = TPC.NRTPCLASSIFICAPARC
          LEFT JOIN SEGMERCADO SM
            ON PN.CDSEGMER = SM.CDSEGMER
          LEFT JOIN ATIVCLIENTE AC
            ON PN.CDATIVCLI = AC.CDATIVCLI
          LEFT JOIN TPATIVCLIENTE TC
            ON PN.NRSEQTPATIVCLI = TC.NRSEQTPATIVCLI
          LEFT JOIN TIPOPARCEIRO TP
            ON PN.CDTIPOPARCPRINCIPAL = TP.CDTIPOPARCEIRO
          LEFT JOIN OPERADOR INC
            ON PN.CDOPERINCLUSAO = INC.CDOPERADOR
          LEFT JOIN OPERADOR ATU
            ON PN.CDOPERULTATU = ATU.CDOPERADOR
          LEFT JOIN OPERADOR OP
            ON PN.CDOPERRESPONSAVEL = OP.CDOPERADOR
         WHERE PN.IDPARCFUNDIDO <> 'S'
         GROUP BY TPC.NMCLASSIFICAPARC,
               TPC.NRTPCLASSIFICAPARC,
               PN.NRPARCNEGOCIO,
               PN.CDSEGMER,
               SM.DSSEGMER,
               PN.CDTIPOPARCPRINCIPAL,
               TP.NMTIPOPARCEIRO,
               PN.CDTIPOINSCRICAO,
               PN.NMPRINCIPALPARC,
               PN.NMSECUNDARIPARC,
               PN.DTNASCIFUNDPARC,
               PN.NRINSCRICAOPARC,
               PN.IDPESSOAFISICA,
               PN.IDINSTITUICAO,
               PN.NRORG,
               PN.IDATIVO,
               PN.DTINCLUSAO,
               PN.DTULTATU,
               PN.CDOPERRESPONSAVEL,
               PN.NRORGINCLUSAO,
               PN.CDOPERINCLUSAO,
               PN.NRORGULTATU,
               PN.CDOPERULTATU,
               PN.DSDEPARTAMENTO,
               PN.CDATIVCLI,
               AC.DSATIVCLI,
               PN.NRSEQTPATIVCLI,
               TC.DSTPATIVCLIENTE,
               PN.IDIDIOMA,
               INC.NMOPERADOR,
               ATU.NMOPERADOR,
               OP.NMOPERADOR,
               OP.NRPARCNEGOCIO,
               INC.NMOPERADOR,
               ATU.NMOPERADOR,
               OP.NMOPERADOR
         ORDER BY PN.NMPRINCIPALPARC";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getOperator() {

      $sql = "SELECT CDOPERADOR, NMOPERADOR || ' (' || DECODE(IDATIVO, 'S', 'Ativo', 'Inativo') || ')' NMOPERADOR
                FROM OPERADOR
                ORDER BY NMOPERADOR";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);

    }

    public function getPartnerClassification() {

      $sql = "SELECT NRTPCLASSIFICAPARC, NMCLASSIFICAPARC
                  FROM TIPOCLASSIFICAPARC
                  ORDER BY NMCLASSIFICAPARC";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getTypeOfPartner() {

      $sql = "SELECT CDTIPOPARCEIRO, NMTIPOPARCEIRO
                 FROM TIPOPARCEIRO
                WHERE IDATIVO = 'S'
                AND  CDTIPOPARCEIRO  NOT IN ('ESTRUTURA', 'TRANSPORTADORA')
                ORDER BY NMTIPOPARCEIRO";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getMarketSegment() {

      $sql = "SELECT CDSEGMER, DSSEGMER
                 FROM SEGMERCADO
                WHERE IDATIVO = 'S'
                ORDER BY DSSEGMER";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getBranchOfActivity() {

      $sql = "SELECT CDATIVCLI, DSATIVCLI
                FROM ATIVCLIENTE
                WHERE IDATIVO = 'S'
                ORDER BY DSATIVCLI";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getTypeOfActivity() {

      $sql = "SELECT NRSEQTPATIVCLI, DSTPATIVCLIENTE
                FROM TPATIVCLIENTE
                WHERE IDATIVO = 'S'
                ORDER BY DSTPATIVCLIENTE";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getCountry() {

      $sql = "SELECT CDPAIS, NMPAIS
                 FROM PAIS
                WHERE IDATIVO = 'S'
                ORDER BY NMPAIS";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getState($parametro) {
      $sql = "SELECT SGESTADO, NMESTADO
                 FROM ESTADO
                WHERE IDATIVO = 'S'
                AND CDPAIS = :CDPAIS
                ORDER BY NMESTADO";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function getCity($parametro) {

      $sql = "SELECT CDMUNICIPIO, NMMUNICIPIO
                 FROM MUNICIPIO
                WHERE IDATIVO = 'S'
                AND CDPAIS = :CDPAIS
                AND SGESTADO = :SGESTADO
                ORDER BY NMMUNICIPIO";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function getDistrict($parametro) {

      $sql = "SELECT CDBAIRRO, NMBAIRRO
                FROM BAIRRO
                WHERE IDATIVO = 'S'
                AND SGESTADO = :SGESTADO
                AND CDPAIS = :CDPAIS
                AND CDMUNICIPIO = :CDMUNICIPIO
                ORDER BY NMBAIRRO";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function findCodeDistrict($parametros) {

        $sqlAlter1 = "ALTER SESSION SET NLS_COMP=LINGUISTIC";

        $std = $this->connection->prepare($sqlAlter1);
        $std->execute();

        $sqlAlter2 = "ALTER SESSION SET NLS_SORT=BINARY_AI";

        $std = $this->connection->prepare($sqlAlter2);
        $std->execute();

        $sql = "SELECT CDBAIRRO, NMBAIRRO, SGESTADO
                  FROM BAIRRO
                  WHERE NMBAIRRO LIKE :NMBAIRRO
                  AND IDATIVO = 'S'
                  AND SGESTADO = :SGESTADO
                  AND CDPAIS = :CDPAIS
                  AND CDMUNICIPIO = :CDMUNICIPIO";


        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
        return $std->fetchAll();
    }

    public function getSpecificBusinessPartner($parametro) {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI'";

        $std = $this->connection->prepare($sqlAlter);
        $std->execute();

        $sql = "SELECT TPC.NMCLASSIFICAPARC,
                 TPC.NRTPCLASSIFICAPARC,
                 PN.NRPARCNEGOCIO,
                 PN.CDSEGMER,
                 SM.DSSEGMER,
                 PN.CDTIPOPARCPRINCIPAL,
                 TP.NMTIPOPARCEIRO AS NMTIPOPARCPRINCIPAL,
                 PN.CDTIPOINSCRICAO,
                 PN.NMPRINCIPALPARC,
                 PN.NMSECUNDARIPARC,
                 PN.DTNASCIFUNDPARC,
                 PN.NRINSCRICAOPARC,
                 PN.IDPESSOAFISICA,
                 PN.IDINSTITUICAO,
                 PN.NRORG,
                 PN.IDATIVO,
                 TO_DATE( TO_CHAR(PN.DTINCLUSAO, 'DD/MM/YYYY HH24:MI')) DTINCLUSAO,
                 TO_DATE( TO_CHAR(PN.DTULTATU, 'DD/MM/YYYY HH24:MI')) DTULTATU,
                 PN.CDOPERRESPONSAVEL,
                 PN.NRORGINCLUSAO,
                 PN.CDOPERINCLUSAO,
                 PN.NRORGULTATU,
                 PN.CDOPERULTATU,
                 PN.DSDEPARTAMENTO,
                 PN.CDATIVCLI,
                 AC.DSATIVCLI,
                 PN.NRSEQTPATIVCLI,
                 TC.DSTPATIVCLIENTE,
                 PN.IDIDIOMA,
                 LISTAGG(PA.CDTIPOPARCEIRO, ', ') WITHIN GROUP(ORDER BY PA.CDTIPOPARCEIRO) TIPODEPARCEIRO,
                 INC.NMOPERADOR AS NMOPERINCLUSAO,
                 ATU.NMOPERADOR AS NMOPERULTATU,
                 OP.NMOPERADOR AS NMOPERRESPONSAVEL,
                 PN.CDINSCMUNI,
                 PN.CDINSCESTA
            FROM PARCNEGOCIO PN
            LEFT JOIN PARCERIA PA
              ON PN.NRPARCNEGOCIO = PA.NRPARCNEGOCIO
             AND PA.IDATIVO       = 'S'
            LEFT JOIN TIPOCLASSIFICAPARC TPC
              ON PN.NRTPCLASSIFICAPARC = TPC.NRTPCLASSIFICAPARC
            LEFT JOIN SEGMERCADO SM
              ON PN.CDSEGMER = SM.CDSEGMER
            LEFT JOIN ATIVCLIENTE AC
              ON PN.CDATIVCLI = AC.CDATIVCLI
            LEFT JOIN TPATIVCLIENTE TC
              ON PN.NRSEQTPATIVCLI = TC.NRSEQTPATIVCLI
            LEFT JOIN TIPOPARCEIRO TP
              ON PN.CDTIPOPARCPRINCIPAL = TP.CDTIPOPARCEIRO
            LEFT JOIN OPERADOR INC
              ON PN.CDOPERINCLUSAO = INC.CDOPERADOR
            LEFT JOIN OPERADOR ATU
              ON PN.CDOPERULTATU = ATU.CDOPERADOR
            LEFT JOIN OPERADOR OP
              ON PN.CDOPERRESPONSAVEL = OP.CDOPERADOR
           WHERE PN.IDPARCFUNDIDO <> 'S'
           AND PN.NRPARCNEGOCIO = :NRPARCNEGOCIO
           GROUP BY TPC.NMCLASSIFICAPARC,
                 TPC.NRTPCLASSIFICAPARC,
                 PN.NRPARCNEGOCIO,
                 PN.CDSEGMER,
                 SM.DSSEGMER,
                 PN.CDTIPOPARCPRINCIPAL,
                 TP.NMTIPOPARCEIRO,
                 PN.CDTIPOINSCRICAO,
                 PN.NMPRINCIPALPARC,
                 PN.NMSECUNDARIPARC,
                 PN.DTNASCIFUNDPARC,
                 PN.NRINSCRICAOPARC,
                 PN.IDPESSOAFISICA,
                 PN.IDINSTITUICAO,
                 PN.NRORG,
                 PN.IDATIVO,
                 PN.DTINCLUSAO,
                 PN.DTULTATU,
                 PN.CDOPERRESPONSAVEL,
                 PN.NRORGINCLUSAO,
                 PN.CDOPERINCLUSAO,
                 PN.NRORGULTATU,
                 PN.CDOPERULTATU,
                 PN.DSDEPARTAMENTO,
                 PN.CDATIVCLI,
                 AC.DSATIVCLI,
                 PN.NRSEQTPATIVCLI,
                 TC.DSTPATIVCLIENTE,
                 PN.IDIDIOMA,
                 INC.NMOPERADOR,
                 ATU.NMOPERADOR,
                 OP.NMOPERADOR,
                 OP.NRPARCNEGOCIO,
                 INC.NMOPERADOR,
                 ATU.NMOPERADOR,
                 OP.NMOPERADOR,
                 PN.CDINSCMUNI,
                 PN.CDINSCESTA
           ORDER BY PN.NMSECUNDARIPARC, PN.NMPRINCIPALPARC";

        $std = $this->connection->prepare($sql);
        $std->execute($parametro);
        return $std->fetchAll();
      }

    public function insertNewBusinessPartner($parametros) {
    // debugApi([$parametros]);

      $sql = "INSERT INTO PARCNEGOCIO (NRPARCNEGOCIO, NRORG, CDSEGMER, NMPRINCIPALPARC, NMSECUNDARIPARC,
              DTNASCIFUNDPARC, NRINSCRICAOPARC, IDATIVO, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO,
              NRORGULTATU, CDOPERULTATU, CDTIPOPARCPRINCIPAL, CDTIPOINSCRICAO, IDPESSOAFISICA, IDINSTITUICAO,
              DSDEPARTAMENTO, IDIDIOMA, CDATIVCLI, NRSEQTPATIVCLI, IDPARCFUNDIDO, CDOPERRESPONSAVEL, NRTPCLASSIFICAPARC,
              DSDIRLOGOMARCA, NRINSCESTADUAL, CDINSCESTA, CDINSCMUNI)
                VALUES (:NRPARCNEGOCIO,
                        :NRORG,
                        :CDSEGMER,
                        :NMPRINCIPALPARC,
                        :NMSECUNDARIPARC,
                        :DTNASCIFUNDPARC,
                        :NRINSCRICAOPARC,
                        'S',
                        SYSDATE,
                        NULL,
                        :NRORGINCLUSAO,
                        :CDOPERINCLUSAO,
                        NULL,
                        NULL,
                        :CDTIPOPARCPRINCIPAL,
                        :CDTIPOINSCRICAO,
                        :IDPESSOAFISICA,
                        :IDINSTITUICAO,
                        NULL,
                        NULL,
                        :CDATIVCLI,
                        :NRSEQTPATIVCLI,
                        'N',
                        :CDOPERRESPONSAVEL,
                        :NRTPCLASSIFICAPARC,
                        NULL,
                        NULL,
                        :CDINSCESTA,
                        :CDINSCMUNI)";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

    public function insertPartnership($parametros) {

      $sql = "INSERT INTO PARCERIA
                VALUES (:NRPARCERIA,
                        :NRPARCNEGOCIO,
                        :CDTIPOPARCEIRO,
                        :NRORG,
                        :IDATIVO,
                        SYSDATE,
                        NULL,
                        :NRORGINCLUSAO,
                        :CDOPERINCLUSAO,
                        NULL,
                        NULL,
                        :NRPARCORIGEM)";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

    public function insertCLIENTE($parametros) {

      $sql = "INSERT INTO CLIENTE (CDCLIENTE, IDTPIJURCLIE, NRINSJURCLIE, NMRAZSOCCLIE, NMFANTCLIE,
                                   NRORG, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, NRPARCNEGOCIO)
                VALUES (:CDCLIENTE, :IDTPIJURCLIE, :NRINSJURCLIE, :NMRAZSOCCLIE, :NMFANTCLIE, :NRORG, SYSDATE,
                        :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRPARCNEGOCIO)";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

    public function insertFORNECEDOR($parametros) {

      $sql = "INSERT INTO FORNECEDOR (CDFORNECED, IDTPIJURFORN, NRINSJURFORN, NMRAZSOCFORN, NMFANTFORN, NRORG,
                                      DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, NRPARCNEGOCIO)
                VALUES (:CDFORNECED, :IDTPIJURFORN, :NRINSJURFORN, :NMRAZSOCFORN, :NMFANTFORN, :NRORG,
                SYSDATE, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRPARCNEGOCIO)";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

    public function insertVENDEDOR($parametros) {

      $sql = "INSERT INTO VENDEDOR(CDVENDEDOR, IDTPIJURVEN, NRINSJURVEN, NMRAZSOCVEN, NMFANVEN, NRORG, DTINCLUSAO,
                                   NRORGINCLUSAO, CDOPERINCLUSAO, NRPARCNEGOCIO)
                VALUES(:CDVENDEDOR, :IDTPIJURVEN, :NRINSJURVEN, :NMRAZSOCVEN, :NMFANVEN, :NRORG, SYSDATE,
                       :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRPARCNEGOCIO)";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

    public function insertPROSPECT($parametros) {

      $sql = "INSERT INTO PROSPECT (CDPROSPECT, IDTPIJURPROS, NRINSJURPROS, NMRAZSOCPROS, NMFANTPROS,
                                    NRORG, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO,NRPARCNEGOCIO, IDATIVO, NRPARCORIGEM)
                VALUES (:CDPROSPECT, :IDTPIJURPROS, :NRINSJURPROS, :NMRAZSOCPROS, :NMFANTPROS,
                        :NRORG, SYSDATE, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRPARCNEGOCIO, :IDATIVO, :NRPARCORIGEM)";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

    public function updateSpecificBusinessPartner($parametros) {
    // debugApi([$parametros]);
      $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

      $std = $this->connection->prepare($sqlAlter);
      $std->execute();
      
      $sql = "UPDATE PARCNEGOCIO
                SET CDSEGMER = :CDSEGMER,
                    NMPRINCIPALPARC = :NMPRINCIPALPARC,
                    NMSECUNDARIPARC = :NMSECUNDARIPARC,
                    DTNASCIFUNDPARC = :DTNASCIFUNDPARC,
                    NRINSCRICAOPARC = :NRINSCRICAOPARC,
                    IDATIVO = :IDATIVO,
                    DTULTATU = SYSDATE,
                    NRORGULTATU = :NRORGULTATU,
                    CDOPERULTATU = :CDOPERULTATU,
                    CDTIPOPARCPRINCIPAL = :CDTIPOPARCPRINCIPAL,
                    CDTIPOINSCRICAO = :CDTIPOINSCRICAO,
                    IDPESSOAFISICA = :IDPESSOAFISICA,
                    IDINSTITUICAO = :IDINSTITUICAO,
                    CDATIVCLI = :CDATIVCLI,
                    NRSEQTPATIVCLI = :NRSEQTPATIVCLI,
                    CDOPERRESPONSAVEL = :CDOPERRESPONSAVEL,
                    NRTPCLASSIFICAPARC = :NRTPCLASSIFICAPARC,
                    CDINSCESTA = :CDINSCESTA,
                    CDINSCMUNI = :CDINSCMUNI
                WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

    public function searchForExistingPartnerTypes($parametros) {

      $sql = "SELECT CDTIPOPARCEIRO FROM PARCERIA
                WHERE NRPARCNEGOCIO = ".$parametros['NRPARCNEGOCIO']."
                AND CDTIPOPARCEIRO NOT IN (".$parametros['CDTIPOPARCEIRO'].")
                AND IDATIVO = 'S'";

      $std = $this->connection->prepare($sql);
      $std->execute();
      return $std->fetchAll();

    }

    public function searchForInactivatePartnerTypes($parametros) {

      $sql = "SELECT CDTIPOPARCEIRO FROM PARCERIA
                WHERE NRPARCNEGOCIO = ".$parametros."
                AND IDATIVO = 'N'";

      $std = $this->connection->prepare($sql);
      $std->execute();
      return $std->fetchAll();
    }

    public function inactivateOrActivatePartnerType($parametros) {

      $sql = "UPDATE PARCERIA
                 SET IDATIVO = :IDATIVO,
                     DTULTATU =  SYSDATE,
                     NRORGULTATU = :NRORGULTATU,
                     CDOPERULTATU = :CDOPERULTATU
                WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO
                  AND CDTIPOPARCEIRO = :CDTIPOPARCEIRO
                  AND NRORG = :NRORG";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);

    }

    public function searchPartnesTypes($parametros) {

     $sql = "SELECT * FROM PARCERIA
                WHERE NRPARCNEGOCIO = ".$parametros['NRPARCNEGOCIO']."
                  AND CDTIPOPARCEIRO = '".$parametros['CDTIPOPARCEIRO']."'";

      $std = $this->connection->prepare($sql);
      $std->execute();
      return $std->fetchAll();
    }

    public function updateCLIENTE($parametros) {

      $sql = "UPDATE CLIENTE
                SET IDCLIEATIV = :IDCLIEATIV,
                    IDATIVO =  :IDATIVO,
                    DTULTATU = SYSDATE,
                    NRORGULTATU = :NRORGULTATU,
                    CDOPERULTATU = :CDOPERULTATU
              WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

    public function updateFORNECEDOR($parametros) {

      $sql = "UPDATE FORNECEDOR
                  SET IDATIVO = :IDATIVO,
                      DTULTATU = SYSDATE,
                      NRORGULTATU = :NRORGULTATU,
                      CDOPERULTATU = :CDOPERULTATU
              WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

    public function updateVENDEDOR($parametros) {

      $sql = "UPDATE VENDEDOR
                  SET IDATIVO = :IDATIVO,
                      DTULTATU = SYSDATE,
                      NRORGULTATU = :NRORGULTATU,
                      CDOPERULTATU = :CDOPERULTATU
                WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }


    public function updatePROSPECT($parametros) {

      $sql = "UPDATE PROSPECT
                  SET IDATIVO = :IDATIVO,
                      DTULTATU = SYSDATE,
                      NRORGULTATU = :NRORGULTATU,
                      CDOPERULTATU = :CDOPERULTATU
                WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

    // ------------------------- ENDEREÇO --------------------------------------------------------------------------

    public function getBusinessPartnerAddress($parametro) {

        $sql = "SELECT EP.*, P.NMPAIS, E.NMESTADO, M.NMMUNICIPIO, B.NMBAIRRO, L.DSLOGRADOURO, TE.NMTIPOENDERECO
                  FROM ENDERECOPARC EP
                  LEFT JOIN PAIS P
                       ON P.CDPAIS = EP.CDPAIS
                      AND P.NRORG = EP.NRORG
                  LEFT JOIN ESTADO E
                       ON E.SGESTADO = EP.SGESTADO
                      AND E.CDPAIS = P.CDPAIS AND E.NRORG = EP.NRORG
                  LEFT JOIN MUNICIPIO M
                       ON M.CDMUNICIPIO = EP.CDMUNICIPIO
                      AND M.SGESTADO = E.SGESTADO
                      AND M.NRORG = EP.NRORG
                  LEFT JOIN BAIRRO B
                       ON B.CDBAIRRO = EP.CDBAIRRO
                      AND B.CDMUNICIPIO = M.CDMUNICIPIO
                      AND(B.NRORG = EP.NRORG OR B.NRORG = 0)
                  LEFT JOIN LOGRADOURO L
                       ON L.CDLOGRADOURO = EP.CDLOGRADOURO
                      AND L.NRORG = EP.NRORG
                  LEFT JOIN TIPOENDERECO TE
                       ON TE.CDTIPOENDERECO = EP.CDTIPOENDERECO
                      AND TE.NRORG = EP.NRORG
                  WHERE EP.IDATIVO = 'S'
                  AND EP.NRPARCNEGOCIO = :NRPARCNEGOCIO";

         return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function getSpecificAddress($parametro) {

        $sql = "SELECT EP.*, P.NMPAIS, E.NMESTADO, M.NMMUNICIPIO, B.NMBAIRRO, L.DSLOGRADOURO, TE.NMTIPOENDERECO
                  FROM ENDERECOPARC EP
                  LEFT JOIN PAIS P
                       ON P.CDPAIS = EP.CDPAIS
                      AND P.NRORG = EP.NRORG
                  LEFT JOIN ESTADO E
                       ON E.SGESTADO = EP.SGESTADO
                      AND E.CDPAIS = P.CDPAIS AND E.NRORG = EP.NRORG
                  LEFT JOIN MUNICIPIO M
                       ON M.CDMUNICIPIO = EP.CDMUNICIPIO
                      AND M.SGESTADO = E.SGESTADO
                      AND M.NRORG = EP.NRORG
                  LEFT JOIN BAIRRO B
                       ON B.CDBAIRRO = EP.CDBAIRRO
                      AND B.CDMUNICIPIO = M.CDMUNICIPIO
                      AND(B.NRORG = EP.NRORG OR B.NRORG = 0)
                  LEFT JOIN LOGRADOURO L
                       ON L.CDLOGRADOURO = EP.CDLOGRADOURO
                      AND L.NRORG = EP.NRORG
                  LEFT JOIN TIPOENDERECO TE
                       ON TE.CDTIPOENDERECO = EP.CDTIPOENDERECO
                      AND TE.NRORG = EP.NRORG
                  WHERE EP.IDATIVO = 'S'
                  AND EP.NRENDERECOPARC = :NRENDERECOPARC";

        $std = $this->connection->prepare($sql);
        $std->execute($parametro);
        return $std->fetchAll();
    }

    public function insertNewAddress($parametros) {

      $sql = "INSERT INTO ENDERECOPARC (NRENDERECOPARC, NRPARCNEGOCIO, CDTIPOENDERECO, NRORG, IDATIVO, DTINCLUSAO,
              NRORGINCLUSAO, CDOPERINCLUSAO, CDPAIS, SGESTADO, CDMUNICIPIO, CDBAIRRO, NMBAIRROENDERECO, DSCOMPLEENDERECO, NRCEPENDERECO, DSENDERECO, NRIMOVELENDERECO, DSREFERENCIAENDE)
                VALUES (:NRENDERECOPARC,
                        :NRPARCNEGOCIO,
                        :CDTIPOENDERECO,
                        :NRORG,
                        'S',
                        SYSDATE,
                        :NRORGINCLUSAO,
                        :CDOPERINCLUSAO,
                        :CDPAIS,
                        :SGESTADO,
                        :CDMUNICIPIO,
                        :CDBAIRRO,
                        :NMBAIRROENDERECO,
                        :DSCOMPLEENDERECO,
                        :NRCEPENDERECO,
                        :DSENDERECO,
                        :NRIMOVELENDERECO,
                        :DSREFERENCIAENDE)";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

    public function deleteAddress($parametros) {

      $sql = "DELETE FROM ENDERECOPARC
                WHERE NRENDERECOPARC IN (".$parametros['NRENDERECOPARC'].")
                  AND NRPARCNEGOCIO = ".$parametros['NRPARCNEGOCIO'];

      $std = $this->connection->prepare($sql);
      $std->execute();
    }

    public function updateAddress($parametros) {
      // debugApi([$parametros]);

      $sql = "UPDATE ENDERECOPARC
                  SET CDTIPOENDERECO = :CDTIPOENDERECO,
                      IDATIVO = 'S',
                      DTULTATU = SYSDATE,
                      NRORGULTATU = :NRORGULTATU,
                      CDOPERULTATU = :CDOPERULTATU,
                      CDPAIS = :CDPAIS,
                      SGESTADO = :SGESTADO,
                      CDMUNICIPIO = :CDMUNICIPIO,
                      CDBAIRRO = :CDBAIRRO,
                      NMBAIRROENDERECO = :NMBAIRROENDERECO,
                      DSCOMPLEENDERECO = :DSCOMPLEENDERECO,
                      NRCEPENDERECO = :NRCEPENDERECO,
                      DSENDERECO = :DSENDERECO,
                      NRIMOVELENDERECO = :NRIMOVELENDERECO,
                      DSREFERENCIAENDE = :DSREFERENCIAENDE
                WHERE NRENDERECOPARC = :NRENDERECOPARC
                  AND NRPARCNEGOCIO = :NRPARCNEGOCIO";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }
    //  ---------------------------------- FUNÇÕES DA TAB DE FORMAS DE COMUNICAÇÃO ----------------------------------

    public function getListWaysOfCommunication() {

        $sql = "SELECT CDFORMACOMU, NMFORMACOMU, DTULTATUFORC, NRORG, DTINCLUSAO, DTULTATU, NRORGINCLUSAO,
                  CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU, IDATIVO
                    FROM FORMACOMU
                    WHERE IDATIVO = 'S'
                    ORDER BY NMFORMACOMU";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getWayOfCommunication($parametro) {

        $sql = "SELECT CP.NRCOMUNICAPARC,
                  CP.NRPARCNEGOCIO,
                  CP.CDFORMACOMU,
                  CP.NRENDERECOPARC,
                  CP.CDPREFIXCOMUPARC,
                  CP.CDCOMUNICAPARC,
                  CP.NRORG, CP.NRORGINCLUSAO, CP.NRORGULTATU,
                  CP.IDATIVO,
                  CP.DTINCLUSAO, CP.DTULTATU,
                  CP.CDOPERINCLUSAO, CP.CDOPERULTATU,
                  CP.CDCOMPLECOMUPARC,
                  CP.DSCONTATO,
                  FC.NMFORMACOMU
              FROM COMUNICAPARC CP
              JOIN FORMACOMU FC
                  ON FC.CDFORMACOMU = CP.CDFORMACOMU
              WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO
              ORDER BY FC.NMFORMACOMU, CP.CDCOMUNICAPARC";

         return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function getSpecificWayOfCommunication($parametro) {

      $sql = "SELECT CP.NRCOMUNICAPARC,
                  CP.NRPARCNEGOCIO,
                  CP.CDFORMACOMU,
                  CP.NRENDERECOPARC,
                  CP.CDPREFIXCOMUPARC,
                  CP.CDCOMUNICAPARC,
                  CP.NRORG, CP.NRORGINCLUSAO, CP.NRORGULTATU,
                  CP.IDATIVO,
                  CP.DTINCLUSAO, CP.DTULTATU,
                  CP.CDOPERINCLUSAO, CP.CDOPERULTATU,
                  CP.CDCOMPLECOMUPARC,
                  CP.DSCONTATO,
                  FC.NMFORMACOMU
              FROM COMUNICAPARC CP
              JOIN FORMACOMU FC
                  ON FC.CDFORMACOMU = CP.CDFORMACOMU
              WHERE NRCOMUNICAPARC = :NRCOMUNICAPARC
              ORDER BY FC.NMFORMACOMU";

      $std = $this->connection->prepare($sql);
      $std->execute($parametro);
      return $std->fetchAll();
    }

    public function insertNewCommunicationData($parametros) {

      $sql = "INSERT INTO COMUNICAPARC
              VALUES (:NRCOMUNICAPARC,
                      :NRPARCNEGOCIO,
                      LPAD(:CDFORMACOMU, 2, '0'),
                      :NRENDERECOPARC,
                      :CDPREFIXCOMUPARC,
                      :CDCOMUNICAPARC,
                      :NRORG,
                      'S',
                      SYSDATE,
                      :DTULTATU,
                      :NRORGINCLUSAO,
                      :CDOPERINCLUSAO,
                      :NRORGULTATU,
                      :CDOPERULTATU,
                      :CDCOMPLECOMUPARC,
                      :DSCONTATO)";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

    public function deleteWayOfCommunication($parametro) {

      $sql = "DELETE FROM COMUNICAPARC
                WHERE NRCOMUNICAPARC IN (".$parametro['NRCOMUNICAPARC'].")";

      $std = $this->connection->prepare($sql);
      $std->execute();
    }

    public function updateWayOfCommunication($parametros) {

      $sql = "UPDATE COMUNICAPARC
                  SET CDFORMACOMU = LPAD(:CDFORMACOMU, 2, '0'),
                      NRENDERECOPARC = :NRENDERECOPARC,
                      CDPREFIXCOMUPARC = :CDPREFIXCOMUPARC,
                      CDCOMUNICAPARC = :CDCOMUNICAPARC,
                      IDATIVO = 'S',
                      DTULTATU = SYSDATE,
                      NRORGULTATU = :NRORGULTATU,
                      CDOPERULTATU = :CDOPERULTATU,
                      CDCOMPLECOMUPARC = :CDCOMPLECOMUPARC,
                      DSCONTATO = :DSCONTATO
                WHERE NRCOMUNICAPARC = :NRCOMUNICAPARC
                  AND NRPARCNEGOCIO = :NRPARCNEGOCIO";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

   //  ---------------------------------- FUNÇÕES DA TAB DE INTERLOCUTOR ----------------------------------
    public function getSectors() {

      $sql = "SELECT *
                FROM SETOR
                WHERE IDATIVO = 'S'
                ORDER BY NMSETOR";

       return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getPositionsOfInterlocutors() {

      $sql = "SELECT CDCARGOINTERLOC, NMCARGOINTERLOC, DTULTATU, NRORG, DTINCLUSAO, NRORGINCLUSAO,
              CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU, IDATIVO
                 FROM CARGOINTERLOC
                WHERE IDATIVO = 'S'
                ORDER BY NMCARGOINTERLOC";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getInterlocutors($parametro) {

      $sql = "SELECT INTER.*,
                SETOR.NMSETOR,
                CARGO.NMCARGOINTERLOC,
                PAIS.NMPAIS,
                ESTADO.NMESTADO,
                MUNICIPIO.NMMUNICIPIO,
                BAIRRO.NMBAIRRO
            FROM CRM_INTERLOCUTOR INTER
            LEFT JOIN CARGOINTERLOC CARGO
                 ON INTER.CDCARGOINTERLOC = CARGO.CDCARGOINTERLOC
                AND INTER.NRORG = CARGO.NRORG
            LEFT JOIN SETOR SETOR
                 ON INTER.CDSETOR = SETOR.CDSETOR
                AND INTER.NRORG = SETOR.NRORG
            LEFT JOIN PAIS
                 ON PAIS.CDPAIS = INTER.CDPAIS
                AND PAIS.NRORG = INTER.NRORG
            LEFT JOIN ESTADO
                 ON ESTADO.SGESTADO = INTER.SGESTADO
                AND ESTADO.CDPAIS = INTER.CDPAIS
                AND ESTADO.NRORG = INTER.NRORG
            LEFT JOIN MUNICIPIO
                 ON MUNICIPIO.CDPAIS = INTER.CDPAIS
                AND MUNICIPIO.SGESTADO = INTER.SGESTADO
                AND MUNICIPIO.CDMUNICIPIO = INTER.CDMUNICIPIO
                AND MUNICIPIO.NRORG = INTER.NRORG
            LEFT JOIN BAIRRO
                 ON BAIRRO.CDPAIS = INTER.CDPAIS
                AND BAIRRO.SGESTADO = INTER.SGESTADO
                AND BAIRRO.CDMUNICIPIO = INTER.CDMUNICIPIO
                AND BAIRRO.CDBAIRRO = INTER.CDBAIRRO
                AND BAIRRO.NRORG = INTER.NRORG
            WHERE INTER.NRPARCNEGOCIO = :NRPARCNEGOCIO
            ORDER BY INTER.NMINTERLOCUTOR";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function getSpecificInterlocutor($parametro) {
      
      $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

      $std = $this->connection->prepare($sqlAlter);
      $std->execute();
      
      $sql = "SELECT INTER.*,
                SETOR.NMSETOR,
                CARGO.NMCARGOINTERLOC,
                PAIS.NMPAIS,
                ESTADO.NMESTADO,
                MUNICIPIO.NMMUNICIPIO,
                BAIRRO.NMBAIRRO
            FROM CRM_INTERLOCUTOR INTER
            LEFT JOIN CARGOINTERLOC CARGO
                 ON INTER.CDCARGOINTERLOC = CARGO.CDCARGOINTERLOC
                AND INTER.NRORG = CARGO.NRORG
            LEFT JOIN SETOR SETOR
                 ON INTER.CDSETOR = SETOR.CDSETOR
                AND INTER.NRORG = SETOR.NRORG
            LEFT JOIN PAIS
                 ON PAIS.CDPAIS = INTER.CDPAIS
                AND PAIS.NRORG = INTER.NRORG
            LEFT JOIN ESTADO
                 ON ESTADO.SGESTADO = INTER.SGESTADO
                AND ESTADO.CDPAIS = INTER.CDPAIS
                AND ESTADO.NRORG = INTER.NRORG
            LEFT JOIN MUNICIPIO
                 ON MUNICIPIO.CDPAIS = INTER.CDPAIS
                AND MUNICIPIO.SGESTADO = INTER.SGESTADO
                AND MUNICIPIO.CDMUNICIPIO = INTER.CDMUNICIPIO
                AND MUNICIPIO.NRORG = INTER.NRORG
            LEFT JOIN BAIRRO
                 ON BAIRRO.CDPAIS = INTER.CDPAIS
                AND BAIRRO.SGESTADO = INTER.SGESTADO
                AND BAIRRO.CDMUNICIPIO = INTER.CDMUNICIPIO
                AND BAIRRO.CDBAIRRO = INTER.CDBAIRRO
                AND BAIRRO.NRORG = INTER.NRORG
            WHERE INTER.NRSEQINTERLOCUTOR = :NRSEQINTERLOCUTOR
            ORDER BY INTER.NMINTERLOCUTOR";

        $std = $this->connection->prepare($sql);
        $std->execute($parametro);
        return $std->fetchAll();
    }

    public function insertNewInterlocutor($parametros) {

     $sql = "INSERT INTO CRM_INTERLOCUTOR (NRSEQINTERLOCUTOR, NMINTERLOCUTOR, NRPARCNEGOCIO, EMAILINTERLOC, NRTELEFONE1,
                NRTELEFONE2, NRTELEFONE3, NRTELEFONE4, CDCARGOINTERLOC, DTNASCIMENTO, IDRECEBEPRESENTE, CDPAIS, SGESTADO,
                CDMUNICIPIO, CDBAIRRO, NRCEPINTERLOCUTOR, DSENDEINTERLOCUTOR, DSCOMPINTERLOCUTOR, NRENDEINTERLOCUTOR,
                NRORG, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, CDSETOR, NRCPFINTERLOC, IDTPSIGNATARIO,
                IDNOMEVINDODAAPI)
              VALUES (".$parametros['NRSEQINTERLOCUTOR'].",
                      '".$parametros['NMINTERLOCUTOR']."',
                      ".$parametros['NRPARCNEGOCIO'].",
                      '".$parametros['EMAILINTERLOC']."',
                      '".$parametros['NRTELEFONE1']."',
                      '".$parametros['NRTELEFONE2']."',
                      '".$parametros['NRTELEFONE3']."',
                      '".$parametros['NRTELEFONE4']."',
                      '".$parametros['CDCARGOINTERLOC']."',
                      '".$parametros['DTNASCIMENTO']."',
                      '".$parametros['IDRECEBEPRESENTE']."',
                      '".$parametros['CDPAIS']."',
                      '".$parametros['SGESTADO']."',
                      '".$parametros['CDMUNICIPIO']."',
                      '".$parametros['CDBAIRRO']."',
                      '".$parametros['NRCEPINTERLOCUTOR']."',
                      '".$parametros['DSENDEINTERLOCUTOR']."',
                      '".$parametros['DSCOMPINTERLOCUTOR']."',
                      '".$parametros['NRENDEINTERLOCUTOR']."',
                      ".$parametros['NRORG'].",
                      'S',
                       SYSDATE,
                      ".$parametros['NRORGINCLUSAO'].",
                      '".$parametros['CDOPERINCLUSAO']."',
                      '".$parametros['CDSETOR']."',
                      '".$parametros['NRCPFINTERLOC']."',
                      '".$parametros['IDTPSIGNATARIO']."',
                      '".$parametros['IDNOMEVINDODAAPI']."')";

        // debugApi([$sql]);
        $std = $this->connection->prepare($sql);
        $std->execute();
    }

    public function deleteInterlocutor($parametros) {
    // debugApi([$parametros]);

      $sql = "DELETE FROM CRM_INTERLOCUTOR
                WHERE NRSEQINTERLOCUTOR IN (".$parametros['NRSEQINTERLOCUTOR'].")
                AND NRPARCNEGOCIO = ".$parametros['NRPARCNEGOCIO'];

      $std = $this->connection->prepare($sql);
      $std->execute();

    }

    public function updateInterlocutor($parametros) {
      
      $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

      $std = $this->connection->prepare($sqlAlter);
      $std->execute();
      
      $sql = "UPDATE CRM_INTERLOCUTOR
                SET   NMINTERLOCUTOR = :NMINTERLOCUTOR,
                      EMAILINTERLOC = :EMAILINTERLOC,
                      NRTELEFONE1 = :NRTELEFONE1,
                      NRTELEFONE2 = :NRTELEFONE2,
                      NRTELEFONE3 = :NRTELEFONE3,
                      NRTELEFONE4 = :NRTELEFONE4,
                      CDCARGOINTERLOC = :CDCARGOINTERLOC,
                      DTNASCIMENTO = :DTNASCIMENTO,
                      IDRECEBEPRESENTE = :IDRECEBEPRESENTE,
                      CDPAIS = :CDPAIS,
                      SGESTADO = :SGESTADO,
                      CDMUNICIPIO = :CDMUNICIPIO,
                      CDBAIRRO = :CDBAIRRO,
                      NRCEPINTERLOCUTOR = :NRCEPINTERLOCUTOR,
                      DSENDEINTERLOCUTOR = :DSENDEINTERLOCUTOR,
                      DSCOMPINTERLOCUTOR = :DSCOMPINTERLOCUTOR,
                      NRENDEINTERLOCUTOR = :NRENDEINTERLOCUTOR,
                      NRORGULTATU = :NRORGULTATU,
                      CDOPERULTATU = :CDOPERULTATU,
                      IDATIVO = 'S',
                      DTULTATU = SYSDATE,
                      CDSETOR = :CDSETOR,
                      NRCPFINTERLOC = :NRCPFINTERLOC,
                      IDTPSIGNATARIO = :IDTPSIGNATARIO,
                      IDNOMEVINDODAAPI = :IDNOMEVINDODAAPI
            WHERE NRSEQINTERLOCUTOR = :NRSEQINTERLOCUTOR
            AND NRPARCNEGOCIO = :NRPARCNEGOCIO";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }
   //  ---------------------------------- FUNÇÕES DA TAB DE DADOS BANCARIOS  ----------------------------------
    public function getBankDetails($parametro) {

      $sql = "SELECT BANCO.NMBANCO,
                  AGENCIA.NMAGENCIA,
                  CONTCORR.DSCONTCORR,
                  TPCONTCORR.DSTPCONTCORR,
                  CONTPARC.*
              FROM CONTCORRPARC CONTPARC
              LEFT JOIN BANCO
                  ON BANCO.CDBANCO = CONTPARC.CDBANCO
                  AND BANCO.NRORG = CONTPARC.NRORG
              LEFT JOIN AGENCIA
                  ON AGENCIA.CDAGENCIA = CONTPARC.CDAGENCIA
                  AND AGENCIA.NRORG = CONTPARC.NRORG
              LEFT JOIN CONTCORR
                  ON CONTCORR.CDCONTCORR = CONTPARC.CDCONTCORR
                  AND CONTCORR.NRORG = CONTPARC.NRORG
              LEFT JOIN TPCONTCORR
                  ON TPCONTCORR.NRTPCONTCORR = CONTPARC.NRTPCONTCORR
                  AND TPCONTCORR.NRORG = CONTPARC.NRORG
              WHERE CONTPARC.NRPARCNEGOCIO = :NRPARCNEGOCIO";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function getSpecificBankDetails($parametro) {

      $sql = "SELECT BANCO.NMBANCO,
                  AGENCIA.NMAGENCIA,
                  CONTCORR.DSCONTCORR,
                  TPCONTCORR.DSTPCONTCORR,
                  CONTPARC.*
              FROM CONTCORRPARC CONTPARC
              LEFT JOIN BANCO
                  ON BANCO.CDBANCO = CONTPARC.CDBANCO
                  AND BANCO.NRORG = CONTPARC.NRORG
              LEFT JOIN AGENCIA
                  ON AGENCIA.CDAGENCIA = CONTPARC.CDAGENCIA
                  AND AGENCIA.NRORG = CONTPARC.NRORG
              LEFT JOIN CONTCORR
                  ON CONTCORR.CDCONTCORR = CONTPARC.CDCONTCORR
                  AND CONTCORR.NRORG = CONTPARC.NRORG
              LEFT JOIN TPCONTCORR
                  ON TPCONTCORR.NRTPCONTCORR = CONTPARC.NRTPCONTCORR
                  AND TPCONTCORR.NRORG = CONTPARC.NRORG
              WHERE CONTPARC.NRCONTCORRPARC = :NRCONTCORRPARC";

        $std = $this->connection->prepare($sql);
        $std->execute($parametro);
        return $std->fetchAll();
    }

    public function insertNewBankDetails($parametros) {

        $sql = "INSERT INTO CONTCORRPARC
                  VALUES (:NRCONTCORRPARC,
                          :NRORG,
                          :NRPARCNEGOCIO,
                          NULL,
                          :CDBANCO,
                          :CDAGENCIA,
                          :CDCONTCORR,
                          :NRTPCONTCORR,
                          SYSDATE,
                          NULL,
                          :NRORGINCLUSAO,
                          :CDOPERINCLUSAO,
                          NULL,
                          NULL)";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function deleteBankDetails($parametros) {
    // debugApi([$parametros]);

      $sql = "DELETE FROM CONTCORRPARC
                WHERE NRCONTCORRPARC IN (".$parametros['NRCONTCORRPARC'].")
                  AND NRPARCNEGOCIO = ".$parametros['NRPARCNEGOCIO'];

      $std = $this->connection->prepare($sql);
      $std->execute();

    }

    public function updateBankDetails($parametros) {

      $sql = "UPDATE CONTCORRPARC
                SET CDREDUCONT = NULL,
                    CDBANCO = :CDBANCO,
                    CDAGENCIA = :CDAGENCIA,
                    CDCONTCORR = :CDCONTCORR,
                    NRTPCONTCORR = :NRTPCONTCORR,
                    DTULTATU = SYSDATE,
                    NRORGULTATU = :NRORGULTATU,
                    CDOPERULTATU = :CDOPERULTATU
                WHERE NRCONTCORRPARC = :NRCONTCORRPARC
                AND NRPARCNEGOCIO = :NRPARCNEGOCIO";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

    public function getBanks() {
      $sql = "SELECT *
                FROM BANCO
                WHERE IDATIVO = 'S'
                ORDER BY NMBANCO";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getAgencies($parametro) {

      $sql = "SELECT *
                FROM AGENCIA
                WHERE IDATIVO = 'S'
                AND CDBANCO = :CDBANCO
                ORDER BY NMAGENCIA";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function getCheckingAccount($parametro) {

      $sql = "SELECT *
                FROM CONTCORR
                WHERE CDBANCO = :CDBANCO
                AND CDAGENCIA = :CDAGENCIA
                ORDER BY DSCONTCORR";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametro);
    }

    public function getTypeOfCheckingAccount() {

      $sql = "SELECT NRTPCONTCORR, DSTPCONTCORR, NRORG, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU,
              CDOPERULTATU
                FROM TPCONTCORR";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

  //  ---------------------------------- FUNÇÕES DA TAB DE PARAMETROS DE FATURAMENTO  ----------------------
    public function getBranches() {

      $sql = "SELECT CDFILIAL, CDFILIAL || ' | ' || NMFILIAL AS NMFILIAL
                FROM FILIAL
                ORDER BY CDFILIAL";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getInvoiceSeries() {

      $sql = "SELECT CDEMPRESA, CDINSCESTA, CDINSCMUNI, CDSERIE,
              DSSERIE || ' | ' || CDINSCESTA  || ' | ' || CDINSCMUNI AS DSSERIE
                FROM SERIENF
                WHERE IDATIVO = 'S'
                ORDER BY DSSERIE";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getBillingParameter($parametro) {

      $sql = "SELECT PAR_PARAMFATURA.NRPARAMFATURA,
                PAR_PARAMFATURA.NRPARCNEGOCIO,
                PAR_PARAMFATURA.CDFILIALFATURA,
                FILIAL.NMFILIAL AS NMFILIALFATURA,
                PAR_PARAMFATURA.CDSERIENF,
                SERIENF.DSSERIE,
                PAR_PARAMFATURA.CDEMPRESA,
                PAR_PARAMFATURA.CDINSCESTA,
                PAR_PARAMFATURA.CDINSCMUNI,
                PAR_PARAMFATURA.IDATIVO,
                PAR_PARAMFATURA.NRORG,
                PAR_PARAMFATURA.DTINCLUSAO,
                PAR_PARAMFATURA.CDOPERINCLUSAO,
                PAR_PARAMFATURA.NRORGINCLUSAO,
                PAR_PARAMFATURA.DTULTATU,
                PAR_PARAMFATURA.CDOPERULTATU,
                PAR_PARAMFATURA.NRORGULTATU
            FROM PAR_PARAMFATURA
            LEFT JOIN FILIAL
                ON FILIAL.CDFILIAL = PAR_PARAMFATURA.CDFILIALFATURA
                AND FILIAL.NRORG = PAR_PARAMFATURA.NRORG
            LEFT JOIN SERIENF
                ON SERIENF.CDSERIE = PAR_PARAMFATURA.CDSERIENF
                AND SERIENF.CDEMPRESA = PAR_PARAMFATURA.CDEMPRESA
                AND SERIENF.CDINSCESTA = PAR_PARAMFATURA.CDINSCESTA
                AND SERIENF.CDINSCMUNI = PAR_PARAMFATURA.CDINSCMUNI
                AND SERIENF.NRORG = PAR_PARAMFATURA.NRORG
            WHERE PAR_PARAMFATURA.NRPARCNEGOCIO = :NRPARCNEGOCIO";

      $std = $this->connection->prepare($sql);
      $std->execute($parametro);
      return $std->fetchAll();
    }

    public function insertBillingParameter($parametros) {

      $sql = "INSERT INTO PAR_PARAMFATURA
                VALUES (:NRPARAMFATURA,
                        :NRPARCNEGOCIO,
                        :CDFILIALFATURA,
                        :CDSERIENF,
                        :CDEMPRESA,
                        :CDINSCESTA,
                        :CDINSCMUNI,
                        :NRORG,
                        'S',
                        SYSDATE,
                        NULL,
                        :NRORGINCLUSAO,
                        :CDOPERINCLUSAO,
                        NULL,
                        NULL)";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

    public function updateBillingParameter($parametros) {

      $sql  = "UPDATE PAR_PARAMFATURA
                    SET CDFILIALFATURA =:CDFILIALFATURA,
                        CDSERIENF = :CDSERIENF,
                        CDEMPRESA = :CDEMPRESA,
                        CDINSCESTA = :CDINSCESTA,
                        CDINSCMUNI = :CDINSCMUNI,
                        DTULTATU = SYSDATE,
                        NRORGULTATU = :NRORGULTATU,
                        CDOPERULTATU = :CDOPERULTATU
                WHERE NRPARAMFATURA = :NRPARAMFATURA
                AND NRPARCNEGOCIO = :NRPARCNEGOCIO";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

   public function sendImage($parametros) {

     $sql = "UPDATE PARCNEGOCIO
                SET DSDIRLOGOMARCA = :DSDIRLOGOMARCA,
                    DSTYPELOGOTIPO = :DSTYPELOGOTIPO,
                    QTSIZELOGOTIPO = :QTSIZELOGOTIPO,
                    DTULTATU = SYSDATE
              WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
   }

  public function getImagesLogotype($parametro){

    $sql = "SELECT DSDIRLOGOMARCA
               FROM PARCNEGOCIO
              WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

    $std = $this->connection->prepare($sql);
    $std->execute($parametro);
    return $std->fetchAll();
  }
}

?>