/*TECNISA - TECNOLOGIA EM INFORMTICA

NOME: GRAVA CUSTO LQUIDO

DESCRIO:
PROCEDIMENTO PARA ATUALIZAO DO CUSTO LQUIDO (VRLANCTOEST).

CRIAO:
30/09/98 - ROBERTO A. LOPES MARTINS

MANUTENES:
08/11/99 - PAULO GIOVANNI - CONVERSO P/ SQL-SERVER
*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE 
	        O.NAME = 'CUSTO_LIQUIDO'  AND 
	        TYPE = 'P' 			       AND
	        U.UID = O.UID             AND
	        U.NAME = USER)

DROP PROCEDURE CUSTO_LIQUIDO
GO

CREATE PROCEDURE CUSTO_LIQUIDO @P_FILIAL     VARCHAR(04),         --FILIAL DE LANAMENTO
                               @P_LANCTO     VARCHAR(10),
                               @P_TOTALPROD  NUMERIC(15,6),
                               @P_DIFERENCA  NUMERIC(15,6) = NULL,
                               @P_GRAVVRBRUT VARCHAR(01) = 'N'

AS
   DECLARE @V_CDTIPOOPER VARCHAR(02);
   DECLARE @V_FATOCONV   NUMERIC(15,6);
   DECLARE @V_LANCTOEST  NUMERIC(15,6);
   DECLARE @V_DIFERENCA  NUMERIC(15,6);
   DECLARE @V_QUANTIDADE NUMERIC(15,6);

/* VARIVEIS DO CURSOR C_FATOCONV */
   DECLARE @V_DTLANCMOVI   DATETIME;
   DECLARE @V_NRSEQUITEM   VARCHAR(04);
   DECLARE @V_CDPRODUTO    VARCHAR(10);
   DECLARE @V_CDPRODMOVI   VARCHAR(10);
   DECLARE @V_VRLANCTOEST  NUMERIC(15,5);
   DECLARE @V_VRLANCTOBRUT NUMERIC(15,5);
   DECLARE @V_VRFATOCONV   NUMERIC(10,4);
   DECLARE @V_DTULTCOMPR   DATETIME;
   DECLARE @V_VRULTCOMPR   NUMERIC(15,5);
   DECLARE @V_NRLANCTONF   VARCHAR(10);
   DECLARE @V_QTTOTLANCTO  NUMERIC(12,5);
   DECLARE @V_VRTOTLANCTO  NUMERIC(15,5);
   DECLARE @V_VRUNILANCTO  NUMERIC(15,5);
   DECLARE @V_CDFILIMOVI   VARCHAR(04);
   DECLARE @V_IDTPLANCTO   VARCHAR(01);

   DECLARE @V_COUNT        NUMERIC;

   DECLARE @V_CDFILLANCEST VARCHAR(04);
   DECLARE @V_NRLANC       VARCHAR(10);

   DECLARE @V_VRULTCMPLIQ  NUMERIC(15,5);
   DECLARE @V_VRULTCMPBRU  NUMERIC(15,5);
   DECLARE @V_VRULTCMPLM1  NUMERIC(15,5);
   DECLARE @V_VRULTCMPLM2  NUMERIC(15,5);
   DECLARE @V_VRULTCMPBM1  NUMERIC(15,5);
   DECLARE @V_VRULTCMPBM2  NUMERIC(15,5);

   DECLARE @V_VRINDICE1    NUMERIC;
   DECLARE @V_VRINDICE2    NUMERIC;
   DECLARE @V_CDALMOXARIFE VARCHAR(06);
   DECLARE @V_CDLOCALESTOQ VARCHAR(06);
   DECLARE @V_NRLOTEESTQ   VARCHAR(20);
   DECLARE @V_NRSUBLOTE    VARCHAR(04);
   DECLARE @V_NRLANCESTQ   VARCHAR(10);
   DECLARE @V_CDFILIAL     VARCHAR(04);
   DECLARE @V_NRULTLANCA   VARCHAR(20);

   DECLARE @V_CDINDICEMF   VARCHAR(04);
   DECLARE @V_CDINDICEMF2  VARCHAR(04);

   DECLARE @V_CDTPINDICE   VARCHAR(01);
   DECLARE @V_IDPERVALOR   VARCHAR(01);
   DECLARE @V_CDTPINDICE2  VARCHAR(01);
   DECLARE @V_IDPERVALOR2  VARCHAR(01);
   DECLARE @V_TEXT         VARCHAR(100);
   DECLARE @V_VRCUSTLCMPM1  NUMERIC(15,5);
   DECLARE @V_VRCUSTLCMPM2  NUMERIC(15,5);
   DECLARE @V_VRSEGULCMPM1  NUMERIC(15,5);
   DECLARE @V_VRSEGULCMPM2  NUMERIC(15,5);
   DECLARE @V_VRCUSTLOGLAN  NUMERIC(15,5);
   DECLARE @V_VRSEGULOGLAN  NUMERIC(15,5);
BEGIN
   SET @V_CDTPINDICE   = NULL;
   SET @V_IDPERVALOR   = NULL;
   SET @V_CDINDICEMF   = NULL;
   SET @V_CDTPINDICE2  = NULL;
   SET @V_IDPERVALOR2  = NULL;
   SET @V_CDINDICEMF2  = NULL;
   SET @V_VRINDICE1    = 0;
   SET @V_VRINDICE2    = 0;
   SET @V_CDTIPOOPER   = NULL;
   SET @V_COUNT        = 0;
   SET @V_NRULTLANCA   = NULL;
   SET @V_VRCUSTLCMPM1 = 0;
   SET @V_VRCUSTLCMPM2 = 0;
   SET @V_VRSEGULCMPM1 = 0;
   SET @V_VRSEGULCMPM2 = 0;

   IF (@P_DIFERENCA IS NULL) BEGIN
      SET @V_DIFERENCA = 0;
   END;

   SELECT @V_CDTPINDICE  = MAX(ISNULL(CDTPINDICE,'1')),
          @V_IDPERVALOR  = MAX(ISNULL(IDPERVALOR,'2')),
          @V_CDINDICEMF  = MAX(CDINDICEMF),
          @V_CDTPINDICE2 = MAX(ISNULL(CDTPINDICE2,'1')),
          @V_IDPERVALOR2 = MAX(ISNULL(IDPERVALOR2,'2')),
          @V_CDINDICEMF2 = MAX(CDINDICEMF2)
   FROM PARAMGERAL;

   DECLARE C_FATOCONV CURSOR FOR

   SELECT A.DTLANCMOVI, A.NRSEQUITEM, A.CDPRODUTO,  A.CDPRODMOVI,
          ISNULL(A.VRLANCTOEST,0) AS VRLANCTOEST, ISNULL(A.VRLANCTOBRUT,0) AS VRLANCTOBRUT, B.VRFATOCONV, D.NRLANCTONF,
          QTTOTLANCTO,  A.VRTOTLANCTO,A.VRUNILANCTO,    A.CDFILIMOVI,
          D.IDTPLANCTO, A.CDALMOXARIFE, A.CDLOCALESTOQ, A.NRLOTEESTQ,
          A.NRSUBLOTE,  D.NRLANCESTQ, D.CDFILIAL,
          (VRCUSTLOGLAN/QTTOTLANCTO) AS VRCUSTLOGLAN,
          (VRSEGULOGLAN /QTTOTLANCTO) AS VRSEGULOGLAN
   FROM ITLANCTOEST A, PRODUTO B, PRODFILI C, LANCTOESTOQ D
   WHERE (A.CDFILIAL   = @P_FILIAL)     AND
         (A.NRLANCESTQ = @P_LANCTO)     AND
         (B.CDPRODUTO  = A.CDPRODUTO)   AND
         (C.CDFILIAL   = A.CDFILIMOVI)  AND
         (C.CDPRODUTO  = A.CDPRODMOVI)  AND
         (D.CDFILIAL   = A.CDFILIAL)    AND
         (D.NRLANCESTQ = A.NRLANCESTQ);

   OPEN C_FATOCONV;
   FETCH NEXT FROM C_FATOCONV INTO @V_DTLANCMOVI,   @V_NRSEQUITEM,
                                   @V_CDPRODUTO,    @V_CDPRODMOVI,
                                   @V_VRLANCTOEST,  @V_VRLANCTOBRUT,
                                   @V_VRFATOCONV,   @V_NRLANCTONF,
                                   @V_QTTOTLANCTO,  @V_VRTOTLANCTO,
                                   @V_VRUNILANCTO,  @V_CDFILIMOVI,
                                   @V_IDTPLANCTO,   @V_CDALMOXARIFE,
                                   @V_CDLOCALESTOQ, @V_NRLOTEESTQ,
                                   @V_NRSUBLOTE,    @V_NRLANCESTQ,
                                   @V_CDFILIAL,     @V_VRCUSTLOGLAN,
                                   @V_VRSEGULOGLAN;
   WHILE (@@FETCH_STATUS = 0) BEGIN

      SET @V_VRULTCMPLIQ  = 0;
      SET @V_VRULTCMPBRU  = 0;
      SET @V_VRULTCMPLM1  = 0;
      SET @V_VRULTCMPLM2  = 0;
      SET @V_VRULTCMPBM1  = 0;
      SET @V_VRULTCMPBM2  = 0;

      IF (@V_CDINDICEMF IS NOT NULL) BEGIN

         SELECT @V_VRINDICE1 = MAX(VRINDICE)
         FROM  INDICE I, MOVINDICE M
         WHERE I.CDTPINDICE = @V_CDTPINDICE           AND
               I.IDPERVALOR = @V_IDPERVALOR           AND
               I.CDINDICE   = @V_CDINDICEMF           AND
               M.CDTPINDICE = I.CDTPINDICE            AND
               M.IDPERVALOR = I.IDPERVALOR            AND
               M.CDINDICE   = I.CDINDICE              AND
               M.DTREFIND   = @V_DTLANCMOVI;

         IF (@V_VRINDICE1 IS NOT NULL) BEGIN
            SET @V_TEXT = 'ndice Financeiro Parametrizado na Personalizao do Sistema,
                                             no Possue valor Cadastrado para a Data'+' '+  CONVERT(VARCHAR,@V_DTLANCMOVI,103)
            RAISERROR(@V_TEXT,1 , 16);
         END;
      END;

      IF (@V_CDINDICEMF2 IS NOT NULL) BEGIN

         SELECT @V_VRINDICE2 = MAX(VRINDICE)
         FROM  INDICE I, MOVINDICE M
         WHERE I.CDTPINDICE = @V_CDTPINDICE2           AND
               I.IDPERVALOR = @V_IDPERVALOR2           AND
               I.CDINDICE   = @V_CDINDICEMF2           AND
               M.CDTPINDICE = I.CDTPINDICE             AND
               M.IDPERVALOR = I.IDPERVALOR             AND
               M.CDINDICE   = I.CDINDICE               AND
               M.DTREFIND   = @V_DTLANCMOVI;

        IF (@V_VRINDICE2 IS NOT NULL) BEGIN
            SET @V_TEXT = 'ndice Financeiro Parametrizado na Personalizao do Sistema,
                                             no Possue valor Cadastrado para a Data'+' '+  CONVERT(VARCHAR,@V_DTLANCMOVI,103)
            RAISERROR(@V_TEXT,1,16);
         END;

      END;
      IF (@V_VRFATOCONV IS NULL) OR (@V_VRFATOCONV = 0) BEGIN
         SET @V_FATOCONV = 1;
      END
      ELSE BEGIN
         SET @V_FATOCONV = @V_VRFATOCONV;
      END;

      IF @V_QTTOTLANCTO = 0 BEGIN
         SET @V_QUANTIDADE = 1;
      END
      ELSE BEGIN
         SET @V_QUANTIDADE = @V_QTTOTLANCTO;
      END;

      SET @V_LANCTOEST = 0;

      IF NOT(@P_TOTALPROD = 0) BEGIN --NOTA FISCAL DE COMPLEMENTO
         IF NOT(@P_DIFERENCA IS NULL) BEGIN
            SET @V_DIFERENCA = ((@P_DIFERENCA / @P_TOTALPROD * @V_VRTOTLANCTO / @V_QUANTIDADE) / (@V_FATOCONV));
         END;

         IF @V_VRLANCTOBRUT = 0 BEGIN
            SET @V_LANCTOEST = 0;
         END
         ELSE BEGIN
            SET @V_LANCTOEST = @V_DIFERENCA;
         END;
      END;

      IF NOT (@V_LANCTOEST = 0) BEGIN
-- PARMETRO PARA GRAVAR VALOR BRUTO APENAS PARA ENTRADA SEM NOTA FISCAL
-- SEM IMPOSTO
         IF (@P_GRAVVRBRUT = 'S') BEGIN
            UPDATE ITLANCTOEST
            SET VRLANCTOEST   = VRLANCTOEST  + @V_LANCTOEST,
                VRLANCTOBRUT  = VRLANCTOBRUT + @V_LANCTOEST
            WHERE (CDFILIAL   = @P_FILIAL) AND
                  (NRLANCESTQ = @P_LANCTO) AND
                  (NRSEQUITEM = @V_NRSEQUITEM);
         END
         ELSE BEGIN
            UPDATE ITLANCTOEST
            SET VRLANCTOEST   = VRLANCTOEST + @V_LANCTOEST
            WHERE (CDFILIAL   = @P_FILIAL) AND
                  (NRLANCESTQ = @P_LANCTO) AND
                  (NRSEQUITEM = @V_NRSEQUITEM);
         END;
      END
      ELSE BEGIN
         UPDATE ITLANCTOEST
         SET VRLANCTOEST   = VRLANCTOEST + @V_LANCTOEST
         WHERE (CDFILIAL   = @P_FILIAL) AND
               (NRLANCESTQ = @P_LANCTO) AND
               (NRSEQUITEM = @V_NRSEQUITEM);
      END;

      IF @V_LANCTOEST IS NULL BEGIN
         SET @V_LANCTOEST = 0;
      END;

      IF (@P_GRAVVRBRUT = 'S') BEGIN
         UPDATE ITEMPRODUTO
         SET VRCONTITEM     = VRCONTITEM + (@V_LANCTOEST * QTITEMPROD),
             VRBRUTITEM     = VRBRUTITEM + (@V_LANCTOEST * QTITEMPROD)
         WHERE (CDFILIAL    = @P_FILIAL)              AND
               (NRLANCTONF  = @V_NRLANCTONF) AND
               (NRSEQITPROD = @V_NRSEQUITEM);
      END
      ELSE BEGIN
         UPDATE ITEMPRODUTO
         SET VRCONTITEM     = VRCONTITEM + (@V_LANCTOEST * QTITEMPROD)
         WHERE (CDFILIAL    = @P_FILIAL)              AND
               (NRLANCTONF  = @V_NRLANCTONF) AND
               (NRSEQITPROD = @V_NRSEQUITEM);
      END;

      IF ((@V_QTTOTLANCTO <> 0) AND NOT(@V_QTTOTLANCTO IS NULL)) AND (@V_IDTPLANCTO IN ('0','2','E')) BEGIN
         SET @V_COUNT = 0;

         IF (@V_IDTPLANCTO <> 'S') BEGIN

            SELECT @V_CDTIPOOPER = MAX(CDTIPOOPER)
            FROM NOTAFISCAL
            WHERE (CDFILIAL    = @P_FILIAL)     AND
                  (NRLANCTONF  = @V_NRLANCTONF);

            IF (ISNULL(@V_CDTIPOOPER,'00') <> '06') BEGIN

               SELECT @V_COUNT = COUNT(*),
                      @V_CDFILLANCEST = CDFILLANCEST,
                      @V_NRLANC       = NRLANCESTQ
               FROM CUSTOCMPPROD
               WHERE CDFILIAL       = @V_CDFILIMOVI       AND
                     CDALMOXARIFE   = @V_CDALMOXARIFE     AND
                     CDLOCALESTOQ   = @V_CDLOCALESTOQ     AND
                     NRLOTEESTQ     = @V_NRLOTEESTQ       AND
                     NRSUBLOTE      = @V_NRSUBLOTE        AND
                     CDPRODUTO      = @V_CDPRODMOVI       AND
                     DTCUSTCMPPRO   = @V_DTLANCMOVI
               GROUP BY CDFILLANCEST, NRLANCESTQ;

               IF (@V_IDTPLANCTO <> '0') BEGIN
                  SET @V_VRULTCMPLIQ   = @V_VRLANCTOEST  + @V_LANCTOEST;
                  SET @V_VRULTCMPBRU   = @V_VRLANCTOBRUT + @V_LANCTOEST;
               END
               ELSE BEGIN
                  SET @V_VRULTCMPLIQ   = (@V_VRLANCTOEST/@V_QTTOTLANCTO)/@V_VRFATOCONV  + @V_LANCTOEST;
                  SET @V_VRULTCMPBRU   = (@V_VRLANCTOBRUT/@V_QTTOTLANCTO)/@V_VRFATOCONV + @V_LANCTOEST;
               END;

               IF (@V_CDINDICEMF IS NOT NULL) BEGIN
                  IF (@V_IDTPLANCTO <> '0') BEGIN
                     SET @V_VRULTCMPLM1  = (@V_VRLANCTOEST + @V_LANCTOEST)  * @V_VRINDICE1;
                     SET @V_VRULTCMPBM1  = (@V_VRLANCTOBRUT + @V_LANCTOEST) * @V_VRINDICE1;
                     SET @V_VRCUSTLCMPM1 = (@V_VRCUSTLOGLAN * @V_VRINDICE1);
                     SET @V_VRSEGULCMPM1 = (@V_VRSEGULOGLAN * @V_VRINDICE1);
                  END
                  ELSE BEGIN
                     SET @V_VRULTCMPLM1  = (((@V_VRLANCTOEST/@V_QTTOTLANCTO)/@V_FATOCONV) + @V_LANCTOEST)  * @V_VRINDICE1;
                     SET @V_VRULTCMPBM1  = (((@V_VRLANCTOBRUT/@V_QTTOTLANCTO)/@V_FATOCONV) + @V_LANCTOEST) * @V_VRINDICE1;
                     SET @V_VRCUSTLCMPM1 = @V_VRCUSTLOGLAN * @V_VRINDICE1;
                     SET @V_VRSEGULCMPM1 = @V_VRSEGULOGLAN * @V_VRINDICE1;
                  END;
               END;
               IF (@V_CDINDICEMF2 IS NOT NULL) BEGIN
                  IF (@V_IDTPLANCTO <> '0') BEGIN
                     SET @V_VRULTCMPLM2  = (@V_VRLANCTOEST + @V_LANCTOEST)  * @V_VRINDICE2;
                     SET @V_VRULTCMPBM2  = (@V_VRLANCTOBRUT + @V_LANCTOEST) * @V_VRINDICE2;
                     SET @V_VRCUSTLCMPM2 = (@V_VRCUSTLOGLAN * @V_VRINDICE2);
                     SET @V_VRSEGULCMPM2 = (@V_VRSEGULOGLAN * @V_VRINDICE2);
                  END
                  ELSE BEGIN
                     SET @V_VRULTCMPLM2  = (((@V_VRLANCTOEST/@V_QTTOTLANCTO)/@V_FATOCONV) + @V_LANCTOEST)  * @V_VRINDICE2;
                     SET @V_VRULTCMPBM2  = (((@V_VRLANCTOEST/@V_QTTOTLANCTO)/@V_FATOCONV) + @V_LANCTOEST)  * @V_VRINDICE2;
                     SET @V_VRCUSTLCMPM2 = @V_VRCUSTLOGLAN * @V_VRINDICE2;
                     SET @V_VRSEGULCMPM2 = @V_VRSEGULOGLAN * @V_VRINDICE2;
                  END;
               END;

               IF ( ISNULL(@V_COUNT,0) = 0) BEGIN

                  INSERT INTO CUSTOCMPPROD
                     (CDFILIAL,     DTCUSTCMPPRO,  CDFILLANCEST, NRLANCESTQ,   CDPRODUTO,
                      CDALMOXARIFE, CDLOCALESTOQ,  NRLOTEESTQ,   NRSUBLOTE,    VRLIQCMPPROD,
                      VRBRUCMPPROD, VRLIQCMPPRM1,  VRLIQCMPPRM2,  VRBRUCMPPRM1, VRBRUCMPPRM2,
                      VRCUSTLOGCMP, VRCUSTLCMPM1,   VRCUSTLCMPM2,   VRSEGULOGCMP, VRSEGULCMPM1,
                      VRSEGULCMPM2)
                  VALUES
                     (@V_CDFILIMOVI,   @V_DTLANCMOVI,   @V_CDFILIAL,     @V_NRLANCESTQ,
                      @V_CDPRODMOVI,   @V_CDALMOXARIFE, @V_CDLOCALESTOQ, @V_NRLOTEESTQ,
                      @V_NRSUBLOTE,    @V_VRULTCMPLIQ,  @V_VRULTCMPBRU,  @V_VRULTCMPLM1,
                      @V_VRULTCMPLM2,  @V_VRULTCMPBM1,  @V_VRULTCMPBM2,  @V_VRCUSTLOGLAN,
                      @V_VRCUSTLCMPM1, @V_VRCUSTLCMPM2, @V_VRSEGULOGLAN, @V_VRSEGULCMPM1,
                      @V_VRSEGULCMPM2);
               END
               ELSE BEGIN
                  IF (@V_IDTPLANCTO = '0') BEGIN
                     IF ((@V_CDFILLANCEST = @V_CDFILIAL) AND (@V_NRLANC = @V_NRLANCESTQ)) BEGIN
                        UPDATE CUSTOCMPPROD
                        SET VRLIQCMPPROD  = @V_VRULTCMPLIQ,
                            VRBRUCMPPROD  = @V_VRULTCMPBRU,
                            VRLIQCMPPRM1  = @V_VRULTCMPLM1,
                            VRLIQCMPPRM2  = @V_VRULTCMPLM2,
                            VRBRUCMPPRM1  = @V_VRULTCMPBM1,
                            VRBRUCMPPRM2  = @V_VRULTCMPBM2,
                            NRLANCESTQ    = @V_NRLANCESTQ,
                            CDFILLANCEST  = @V_CDFILIAL,
                            VRCUSTLOGCMP  = @V_VRCUSTLOGLAN,
                            VRCUSTLCMPM1  = @V_VRCUSTLCMPM1,
                            VRCUSTLCMPM2  = @V_VRCUSTLCMPM2,
                            VRSEGULOGCMP  = @V_VRSEGULOGLAN,
                            VRSEGULCMPM1  = @V_VRSEGULCMPM1,
                            VRSEGULCMPM2  = @V_VRSEGULCMPM2
                        WHERE CDFILIAL     = @V_CDFILIMOVI       AND
                              CDALMOXARIFE = @V_CDALMOXARIFE     AND
                              CDLOCALESTOQ = @V_CDLOCALESTOQ     AND
                              NRLOTEESTQ   = @V_NRLOTEESTQ       AND
                              NRSUBLOTE    = @V_NRSUBLOTE        AND
                              CDPRODUTO    = @V_CDPRODMOVI       AND
                              DTCUSTCMPPRO = @V_DTLANCMOVI;
                     END;
                  END
                  ELSE BEGIN

                     SELECT @V_NRULTLANCA = MAX(NRLANCESTQ+CDFILIAL)
                     FROM ITLANCTOEST I
                     WHERE CDFILIMOVI     = @V_CDFILIMOVI       AND
                           CDALMOXARIFE   = @V_CDALMOXARIFE     AND
                           CDLOCALESTOQ   = @V_CDLOCALESTOQ     AND
                           NRLOTEESTQ     = @V_NRLOTEESTQ       AND
                           NRSUBLOTE      = @V_NRSUBLOTE        AND
                           CDPRODUTO      = @V_CDPRODUTO        AND
                           DTLANCMOVI     = @V_DTLANCMOVI;

                     IF (@V_NRULTLANCA = @V_NRLANCESTQ) BEGIN

                        UPDATE CUSTOCMPPROD
                        SET VRLIQCMPPROD  = @V_VRULTCMPLIQ,
                            VRBRUCMPPROD  = @V_VRULTCMPBRU,
                            VRLIQCMPPRM1  = @V_VRULTCMPLM1,
                            VRLIQCMPPRM2  = @V_VRULTCMPLM2,
                            VRBRUCMPPRM1  = @V_VRULTCMPBM1,
                            VRBRUCMPPRM2  = @V_VRULTCMPBM2,
                            NRLANCESTQ    = SUBSTRING(@V_NRULTLANCA,1,10),
                            CDFILLANCEST  = SUBSTRING(@V_NRULTLANCA,11,4),
                            VRCUSTLOGCMP  = @V_VRCUSTLOGLAN,
                            VRCUSTLCMPM1  = @V_VRCUSTLCMPM1,
                            VRCUSTLCMPM2  = @V_VRCUSTLCMPM2,
                            VRSEGULOGCMP  = @V_VRSEGULOGLAN,
                            VRSEGULCMPM1  = @V_VRSEGULCMPM1,
                            VRSEGULCMPM2  = @V_VRSEGULCMPM2
                        WHERE CDFILIAL       = @V_CDFILIMOVI       AND
                              CDALMOXARIFE   = @V_CDALMOXARIFE     AND
                              CDLOCALESTOQ   = @V_CDLOCALESTOQ     AND
                              NRLOTEESTQ     = @V_NRLOTEESTQ       AND
                              NRSUBLOTE      = @V_NRSUBLOTE        AND
                              CDPRODUTO      = @V_CDPRODMOVI       AND
                              DTCUSTCMPPRO   = @V_DTLANCMOVI;
                     END;
                  END;
               END;
            END;
         END;
      END;

      FETCH NEXT FROM C_FATOCONV INTO @V_DTLANCMOVI,   @V_NRSEQUITEM,
                                      @V_CDPRODUTO,    @V_CDPRODMOVI,
                                      @V_VRLANCTOEST,  @V_VRLANCTOBRUT,
                                      @V_VRFATOCONV,   @V_NRLANCTONF,
                                      @V_QTTOTLANCTO,  @V_VRTOTLANCTO,
                                      @V_VRUNILANCTO,  @V_CDFILIMOVI,
                                      @V_IDTPLANCTO,   @V_CDALMOXARIFE,
                                      @V_CDLOCALESTOQ, @V_NRLOTEESTQ,
                                      @V_NRSUBLOTE,    @V_NRLANCESTQ,
                                      @V_CDFILIAL,     @V_VRCUSTLOGLAN,
                                      @V_VRSEGULOGLAN;

   END;

   CLOSE C_FATOCONV;
   DEALLOCATE C_FATOCONV;
END;
GO


-- VERSAO --
EXEC ATUVEROBJ 'CUSTO_LIQUIDO','5.01.007';
GO

